pub struct WorkflowCheckpoint {
pub version: u32,
pub created_at: DateTime<Utc>,
pub sequence: u64,
pub state: WorkflowState,
pub dag: WorkflowDag,
}Expand description
Workflow checkpoint containing both state and DAG for recovery.
Fields
version: u32Checkpoint version for compatibility.
created_at: DateTime<Utc>Timestamp when checkpoint was created.
sequence: u64Checkpoint sequence number (increments with each save).
state: WorkflowStateThe workflow state.
dag: WorkflowDagThe workflow DAG definition.
Implementations
Sourceimpl WorkflowCheckpoint
impl WorkflowCheckpoint
Sourcepub const CURRENT_VERSION: u32 = 1
pub const CURRENT_VERSION: u32 = 1
Current checkpoint format version.
Sourcepub fn new(state: WorkflowState, dag: WorkflowDag, sequence: u64) -> Self
pub fn new(state: WorkflowState, dag: WorkflowDag, sequence: u64) -> Self
Create a new checkpoint from state and DAG.
Sourcepub fn get_pending_tasks(&self) -> Vec<String>
pub fn get_pending_tasks(&self) -> Vec<String>
Get tasks that need to be executed (pending or failed but retriable).
Sourcepub fn get_interrupted_tasks(&self) -> Vec<String>
pub fn get_interrupted_tasks(&self) -> Vec<String>
Get tasks that were running when checkpoint was saved (need retry).
Sourcepub fn get_completed_tasks(&self) -> Vec<String>
pub fn get_completed_tasks(&self) -> Vec<String>
Get tasks that completed successfully.
Sourcepub fn get_failed_tasks(&self) -> Vec<String>
pub fn get_failed_tasks(&self) -> Vec<String>
Get tasks that failed (not retriable).
Sourcepub fn get_skipped_tasks(&self) -> Vec<String>
pub fn get_skipped_tasks(&self) -> Vec<String>
Get tasks that were skipped.
Sourcepub fn are_dependencies_satisfied(&self, task_id: &str) -> bool
pub fn are_dependencies_satisfied(&self, task_id: &str) -> bool
Check if all dependencies for a task are satisfied.
Sourcepub fn get_ready_tasks(&self) -> Vec<String>
pub fn get_ready_tasks(&self) -> Vec<String>
Get tasks ready to execute (pending with satisfied dependencies).
Sourcepub fn prepare_for_resume(&mut self) -> Result<()>
pub fn prepare_for_resume(&mut self) -> Result<()>
Prepare state for resumption by resetting interrupted tasks.